// Copyright (c) 2012 by István Váradi

// This file is part of libxplcommon, a common utility library for
// development related to X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef XPLCOMMON_WAITER_H
#define XPLCOMMON_WAITER_H
//------------------------------------------------------------------------------

// The public interface of the Waiter class common to all platforms
#if 0

//------------------------------------------------------------------------------

namespace xplcommon {

//------------------------------------------------------------------------------

/**
 * Class that can be used to register waitable objects and then wait
 * for them. The objects are registered when they created and a Waiter
 * instance is passed to them.
 */
class Waiter
{
public:
    /**
     * Wait for any if the waitables to become ready or until a
     * timeout expires.
     *
     * If any of the waitables are ready, the function returns immediately.
     *
     * @return true if any of the waitables has become ready, false if
     * the timeout occurs.
     */
    bool wait(int timeout = -1);
};

//------------------------------------------------------------------------------

} /* namespace xplcommon */

//------------------------------------------------------------------------------

#endif // 0, The public interface of the Waiter class common to all platforms

//------------------------------------------------------------------------------

#include "config.h"

//------------------------------------------------------------------------------

#if TARGET_API_WIN32

//------------------------------------------------------------------------------

// #include "win32/Waiter.h"

// namespace xplcommon { typedef win32::Waiter Waiter; }

//------------------------------------------------------------------------------

#else // TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "posix/Waiter.h"

namespace xplcommon { typedef posix::Waiter Waiter; }

//------------------------------------------------------------------------------

#endif // TARGET_API_WIN32

//------------------------------------------------------------------------------
#endif // XPLCOMMON_WAITER_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
